# Meetups

We host regular meetups around the world. We will share the project updates from the vLLM team and have guest speakers from the industry to share their experience and insights.

Please visit [vllm.ai/events](https://vllm.ai/events) to learn more.
